@@ -17,8 +17,8 @@ def cleanup_name(username):
 
 def cleanup_group(group):
   if (type(group) is list or type(group) is tuple) and len(group) == 1:
-    return unicode(group[0])
-  return unicode(group)
+    return str(group[0])
+  return str(group)
 
 
 class LDAPUser(phovea_server.security.User):
@@ -33,7 +33,7 @@ class LDAPUser(phovea_server.security.User):
     if group_prop is not None:
       self.roles = [cleanup_group(g[group_prop]) for g in self.groups]
     else:
-      self.roles = [unicode(g) for g in self.groups]
+      self.roles = [str(g) for g in self.groups]
     self.dn = dn or username
     self.info = info or {}
 
@@ -145,7 +145,7 @@ class LDAPStore(object):
       result = self._authenticate_search_bind(username, password)
 
     if result and self._config.user['required_groups'] and not all(result.has_role(r) for r in self._config.user['required_groups']):
-      log.info('successful login for %s %s but not in required groups %s', result.name, unicode(result.roles), self._config.user['required_groups'])
+      log.info('successful login for %s %s but not in required groups %s', result.name, str(result.roles), self._config.user['required_groups'])
       return None
 
     if result and self._config.cache:
@@ -179,7 +179,7 @@ class LDAPStore(object):
     except LDAPInvalidCredentialsResult:
       log.debug('Authentication was not successful for user "{0}"'.format(username))
       return None
-    except:
+    except Exception:
       log.exception('unknown exception')
       return None
     finally:
@@ -219,7 +219,7 @@ class LDAPStore(object):
     except LDAPInvalidCredentialsResult:
       log.debug('Authentication was not successful for user "{0}"'.format(username))
       return None
-    except:
+    except Exception:
       log.exception('unknown exception')
       return None
     finally:
@@ -240,6 +240,7 @@ class LDAPStore(object):
         AuthenticationResponse
     """
     import re
+    import json
 
     connection = self._make_connection(username, password)
 
@@ -251,7 +252,9 @@ class LDAPStore(object):
       if self._config.get('use_who_am_i'):
         # Luckily there's an LDAP standard operation to help us out
         my_username = connection.extend.standard.who_am_i()
-        my_username = re.sub('^u:\w+\\\\', '', my_username)
+        log.debug('who_am_i(): %r', my_username)
+        # ignore ts lint error, the fix would break the login mechanism
+        my_username = re.sub('^u:\w+\\\\', '', my_username)  # noqa: W605
         log.debug('re.sub: %r', my_username)
       else:
         my_username = username
@@ -272,23 +275,22 @@ class LDAPStore(object):
       search_filter = '(&{0}{1})'.format(self._config.get('user.object_filter'), user_filter)
       log.debug('search_filter: %r', search_filter)
 
-      log.debug('Performing an LDAP Search using filter "{0}", '
-                'base "{1}", and scope "{2}"'.format(search_filter, self.full_user_search_dn,
-                                                     self._config.get('user.search_scope')))
+      log.debug('Performing an LDAP Search using filter "{0}", ''base "{1}", and scope "{2}"'.format(search_filter, self.full_user_search_dn, self._config.get('user.search_scope')))
 
       connection.search(search_base=self.full_user_search_dn, search_filter=search_filter,
                         search_scope=getattr(ldap3, self._config.get('user.search_scope')),
                         attributes=self._config.get('user.attributes') or ldap3.ALL_ATTRIBUTES)
 
       if len(connection.response) > 0:
-        user_info = connection.response[0]['attributes']
-        user_info['dn'] = connection.response[0]['dn']
+        first_entry = json.loads(connection.response_to_json())['entries'][0]
+        user_info = first_entry['attributes']
+        user_info['dn'] = first_entry['dn']
         bind_user = user_info['dn']
       else:
         raise Exception
 
-      if len(connection.response) > 0 and 'memberOf' in connection.response[0]['attributes']:
-        user_groups = connection.response[0]['attributes'].get('memberOf', [])
+      if len(connection.response) > 0 and 'memberOf' in json.loads(connection.response_to_json())['entries'][0]['attributes']:
+        user_groups = json.loads(connection.response_to_json())['entries'][0]['attributes'].get('memberOf', [])
       else:
         user_groups = self._get_user_groups(dn=bind_user, _connection=self._choose(connection))
 
@@ -297,7 +299,7 @@ class LDAPStore(object):
     except LDAPInvalidCredentialsResult:
       log.exception('Authentication was not successful for user "{0}"'.format(username))
       return None
-    except:
+    except Exception:
       log.exception('Cannot find user "{0}" full dn'.format(username))
       return None
     finally:
@@ -324,9 +326,8 @@ class LDAPStore(object):
 
     try:
       connection.bind()
-      log.debug('Successfully bound to LDAP as "{0}"'
-                ' for search_bind method'.format(self._config.get('bind_user_nd') or 'Anonymous'))
-    except:
+      log.debug('Successfully bound to LDAP as "{0}" for search_bind method'.format(self._config.get('bind_user_dn') or 'Anonymous'))
+    except Exception:
       connection.unbind()
       log.exception('unknown')
       return None
@@ -335,9 +336,7 @@ class LDAPStore(object):
     user_filter = '({0}={1})'.format(self._config.get('user.login_attr'), username)
     search_filter = '(&{0}{1})'.format(self._config.get('user.object_filter'), user_filter)
 
-    log.debug('Performing an LDAP Search using '
-              'filter "{0}", base "{1}", and scope "{2}"'.format(search_filter, self.full_user_search_dn,
-                                                                 self._config.get('user.search_scope')))
+    log.debug('Performing an LDAP Search using filter "{0}", base "{1}", and scope "{2}"'.format(search_filter, self.full_user_search_dn, self._config.get('user.search_scope')))
 
     connection.search(search_base=self.full_user_search_dn, search_filter=search_filter,
                       search_scope=getattr(ldap3, self._config.get('user.search_scope')),
@@ -366,7 +365,7 @@ class LDAPStore(object):
           break
         except LDAPInvalidCredentialsResult:
           log.exception('Authentication was not successful for user "{0}"'.format(username))
-        except:  # pragma: no cover
+        except Exception:  # pragma: no cover
           # This should never happen, however in case ldap3 does ever throw an error here,
           # we catch it and log it
           log.exception('unknown')
@@ -382,12 +381,11 @@ class LDAPStore(object):
 
     try:
       connection.bind()
-      log.debug('Successfully bound to LDAP as "{0}" '
-                'for search_bind method'.format(self._config.get('bind_user_nd') or 'Anonymous'))
+      log.debug('Successfully bound to LDAP as "{0}" for search_bind method'.format(self._config.get('bind_user_dn') or 'Anonymous'))
       infos = self._get_user_info(dn, _connection=self._choose(connection))
       groups = self._get_user_groups(dn, _connection=self._choose(connection))
       return LDAPUser(infos.get('name', infos.get('cn', dn)), dn=dn, info=infos, groups=groups, group_prop=self._config.get('group.prop', default='dn'))
-    except:
+    except Exception:
       log.exception('unknown')
       return None
     finally:
@@ -428,9 +426,7 @@ class LDAPStore(object):
       search_filter = '(&{0}({1}={2}))'.format(self._config.get('group.object_filter'),
                                                self._config.get('group.members_attr'), dn)
 
-    log.debug('Searching for groups for specific user with filter "{0}" '
-              ', base "{1}" and scope "{2}"'.format(search_filter, group_search_dn or self.full_group_search_dn,
-                                                    self._config.get('group.search_scope')))
+    log.debug('Searching for groups for specific user with filter "{0}" , base "{1}" and scope "{2}"'.format(search_filter, group_search_dn or self.full_group_search_dn, self._config.get('group.search_scope')))
 
     item_gen = s.paged_search(search_base=group_search_dn or self.full_group_search_dn,
                               search_filter=search_filter,
@@ -455,7 +451,7 @@ class LDAPStore(object):
     if match is not None:
       import re
       match = re.compile(match)
-      results = [r for r in results if match.match(r['dn'])]
+      results = [r for r in list(results) if match.match(r['dn'])]
 
     return results
 
@@ -532,10 +528,11 @@ class LDAPStore(object):
     Returns:
         dict: A dictionary of the object info from LDAP
     """
+    import json
 
     connection = _connection
     if not connection:
-      connection = self._make_connection(bind_user=self._config.get('bind_user_nd'),
+      connection = self._make_connection(bind_user=self._config.get('bind_user_dn'),
                                          bind_password=self._config.get('bind_user_password')
                                          )
       connection.bind()
@@ -544,8 +541,9 @@ class LDAPStore(object):
 
     data = None
     if len(connection.response) > 0:
-      data = connection.response[0]['attributes']
-      data['dn'] = connection.response[0]['dn']
+      first_entry = json.loads(connection.response_to_json())['entries'][0]
+      data = first_entry['attributes']
+      data['dn'] = first_entry['dn']
 
     if not _connection:
       # We made a connection, so we need to kill it.
